<?php
/**
 *
 * @category        modules
 * @package         Smart Image
 * @author          Ruud Eisinga / Dev4me
 * @link			https://www.dev4me.com/
 * @license         http://www.gnu.org/licenses/gpl.html
 * @platform        WebsiteBaker 2.8.x
 * @requirements    PHP 7.0 and higher
 * @version         0.1.2
 * @lastmodified    July 23, 2020
 *
 */

global $sizes;
$sizes = array(1920,1280,960,640,320);

function simage_image_resize ( $image, $save_as, $max_width = 0, $max_height = 0 ) {
	
	simage_image_fix_orientation($image);

	$size = @getimagesize($image);
	if(!$size) return false;
	
	$width = $size[0];
	$height = $size[1];
	
	if($max_width == 0) $max_width = $width;
	if($max_height == 0) $max_height = $height;

	if ($width <= $max_width) {
		// save new filename no resize ??
		return false;
	}


	$x_ratio = $max_width / $width;
	$y_ratio = $max_height / $height;
	if (($width <= $max_width) && ($height <= $max_height) ) {
		$tn_width = $width;
		$tn_height = $height;
	} else if (($x_ratio * $height) < $max_height) {
		$tn_height = ceil($x_ratio * $height);
		$tn_width = $max_width;
	} else {
		$tn_width = ceil($y_ratio * $width);
		$tn_height = $max_height;
	}

	ini_set('memory_limit', '512M');

	$ext = strtolower(substr(strrchr($image, '.'), 1)); // get the file extension
	switch ($ext) { 
		case 'jpg':     // jpg
		case 'jpeg':     // jpg
			$src = imagecreatefromjpeg($image);
			break;
		case 'png':     // png
			$src = imagecreatefrompng($image);
			break;
		case 'gif':     // gif
			$src = imagecreatefromgif($image);
			break;
		default:
			return false;
	}
	
	$dst = imagecreatetruecolor($tn_width,$tn_height);
	imageantialias ($dst, true);

	if($ext == 'png') {
		imagealphablending($dst, false);
		imagesavealpha($dst, true);
		$transparent = imagecolorallocatealpha($dst, 255, 255, 255, 127);
		imagefilledrectangle($dst, 0, 0, $width, $height, $transparent);
	}

	imagecopyresampled ($dst, $src, 0, 0, 0, 0, $tn_width, $tn_height, $width, $height);
	if (function_exists("imageconvolution")) { //sharpen - >= PHP5.1
		$matrix = array( array( -1, -1, -1 ), array( -1, 32, -1 ), array( -1, -1, -1 ) );
		$divisor = 24;
		$offset = 0;
		imageconvolution($dst, $matrix, $divisor, $offset);
	}

	switch ($ext) { 
		case 'jpg':     // jpg
		case 'jpeg':     // jpg
			imagejpeg($dst, $save_as, 80);
			break;
		case 'png':     // png
			imagepng($dst, $save_as, 9);
			break;
		case 'gif':     // gif
			imagegif($dst, $save_as);
			break;
	}

	imagedestroy($src);
	imagedestroy($dst);
	return true;
}
 
 
function simage_image_fix_orientation($filename) {
	if(extension_loaded("exif")) {
		$rotated = false;
		$exif = @exif_read_data($filename);
		if (!empty($exif['Orientation'])) {
			$image = imagecreatefromjpeg($filename);
			switch ($exif['Orientation']) {
				case 3:
					$image = imagerotate($image, 180, 0);
					$rotated = true;
					break;

				case 6:
					$image = imagerotate($image, -90, 0);
					$rotated = true;
					break;

				case 8:
					$image = imagerotate($image, 90, 0);
					$rotated = true;
					break;
			}
			if($rotated) {
				imagejpeg($image, $filename, 90);
				imagedestroy($image);
			}
		}
	}
}

function get_scrset($basedir, $baseurl, $filebase, $fileext, $size = null) {
	global $sizes;
	if($size) {
		if (file_exists($basedir.$filebase.'-'.$size.'.'.$fileext)) {
			return $baseurl.$filebase.'-'.$size.'.'.$fileext.' '.$size.'w';
		}
	} else {
		$srcset = array();
		foreach($sizes as $size) {
			if (file_exists($basedir.$filebase.'-'.$size.'.'.$fileext)) {
				$srcset[] = $baseurl.$filebase.'-'.$size.'.'.$fileext.' '.$size.'w';
			}
		}
		return implode(',',$srcset);
	}		
}